#!/bin/bash

# useful info:
# https://developer.synology.com/developer-guide/synology_package/script_env_var.html

cd "/var/packages/${SYNOPKG_PKGNAME}" || exit 1

if [ -d target/tarballs ]; then
    ARCH=$(./scripts/DetectType.sh)
    if [ "$ARCH" == "" ]; then
        echo "Unsupported architecture"
        exit 1
    fi

    echo "Detected architecture: $ARCH"

    (
      cd target || exit 1
      rm -rf bin || exit 1

      tar xpzf "tarballs/$ARCH.tar.gz" || exit 1
      if [ ! -d bin ]; then
          echo "Malformed archive: $FN";
          exit 1
      fi
      tar xpzf tarballs/common.tar.gz || exit 1
    ) || exit 1
    rm -rf target/tarballs || exit 1
fi

# Fresh install?
if ! [ -d "$SYNOPKG_PKGHOME/.dBpoweramp" ]; then
  # Salvage old pre-DSM7 data
  oldfolder="$SYNOPKG_PKGDEST_VOL/@AssetUPnP-Data/.dBpoweramp"
  echo "Setup: looking for old data in: $oldfolder"
  if [ -d "$oldfolder" ]; then
    # Can't erase old data, only copy
    cp -r "$oldfolder" "$SYNOPKG_PKGHOME"
  fi
else
  echo "Asset profile already present"
fi

  # put AssetReg.bin where it belongs if we are registered
if [ -f target/AssetReg.bin ]; then
  PROFILE="$SYNOPKG_PKGHOME/.dBpoweramp"
  mkdir -p "$PROFILE" || exit 1
  cp target/AssetReg.bin "$PROFILE" || exit 1
fi
